pub const unsafe fn ioctl_read<Device, Result>(
request: ulong,
) -> IoctlReqRead<Device, Result>Expand description
Constructs a new read-only IoctlReq with a fixed request code and
a result type that maps directly to the data the kernel will
provide.
Safety: Callers must ensure that the given request is valid, that
type Arg describes what this request expects to get a pointer to, and
that the kernel will populate the given Arg object with data that is
consistent with Rust’s expectations for the given type.