OpenMode

Trait OpenMode 

pub trait OpenMode { }
A marker trait used with OpenOptions to represent whether a particular set of options must be opened with an additional mode argument.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors