pub unsafe trait ReprMut<T> {
// Required method
fn from_mut_ptr(ptr: *mut T) -> Self;
}Expand description
Trait implemented by types that can represent writable userspace addresses.
Required Methods
Sourcefn from_mut_ptr(ptr: *mut T) -> Self
fn from_mut_ptr(ptr: *mut T) -> Self
Convert the given pointer to the implementing type, without losing any information that the kernel would need to treat the result as a userspace pointer to the same address.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".