SocketProtocol

Trait SocketProtocol 

pub trait SocketProtocol {
    type Device: IoDevice;

    // Required method
    fn raw_protocol_num(&self) -> int;
}
Represents a socket protocol that is compatible with sockets belonging to the domain/family FAMILY.

This trait allows super::File::socket to return a file of the appropriate device type for the selected protocol so that the relevant socket ioctl requests will be supported on its result.

Required Associated Types

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Device: IoDevice> SocketProtocol for SocketProtocolFixed<Device>

Source

type Device = Device