For interacting with tty devices.
Structs
- TtyDevice
- A marker type for
super::Fileobjects that represent tty devices. - Window
Size - Represents the size of the window (or equivalent) that a tty is presented through.
Constants
- TIOCGWINSZ
ioctlrequest for retrieving the current window size of a tty.- TIOCSWINSZ
ioctlrequest for changing the window size of a tty.